@@ -797,7 +797,7 @@ foreach (explode(',', $given) as $item) {
                         </td>
                     </tr>
                 </table>
-                <table id="row_social" class="w-100">
+                <table id="row_social" class="w-100 small">
                     <?php
                     $given = "*";
                     $dateStart = $_POST['dateState'] ?? '';
@@ -1148,7 +1148,7 @@ foreach (explode(',', $given) as $item) {
                 </tr>
                 </tbody>
                 </table>
-                <table id="row_FH" name="row_FH" width="90%">
+                <table id="row_FH" class="small" name="row_FH" width="90%">
                     <tr>
                         <td class="right text-nowrap"><?php echo xlt('Glaucoma'); ?>:</td>
                         <td class="text data"><input type="radio" onclick='negate_radio(this);' id="radio_usertext11" name="radio_usertext11" <?php if (!$result1['usertext11']) {
@@ -1331,7 +1331,7 @@ foreach (explode(',', $given) as $item) {
                     </tr>
                 </table>
             </div>
-            <div class="text-center w-100 mt-0">
+            <div class="text-center w-100 mt-3">
                 <input type="hidden" id="issue_js" name="issue_js" value="test" />
                 <input type="hidden" id="pid" name="pid" value="<?php echo attr($pid); ?>" />
                 <button type='button' id='form_save' name='form_save' class="btn btn-primary btn-save" onclick='top.restoreSession();submit_this_form();'><?php echo xla('Save'); ?></button>
