@@ -434,19 +434,26 @@ if (!empty($glrow)) {
             $GLOBALS[$gl_name] = $gl_value;
         }
     }
+    // Set any user settings that are not also in GLOBALS.
+    // This is for modules support.
+    foreach ($gl_user as $setting) {
+        if (!array_key_exists($setting['setting_label'], $GLOBALS)) {
+            $GLOBALS[$setting['setting_label']] = $setting['setting_value'];
+        }
+    }
 
-  // Language cleanup stuff.
+    // Language cleanup stuff.
     $GLOBALS['language_menu_login'] = false;
-    if ((count($GLOBALS['language_menu_show']) > 1) || $GLOBALS['language_menu_showall']) {
+    if ((!empty($GLOBALS['language_menu_show']) && count($GLOBALS['language_menu_show']) > 1) || $GLOBALS['language_menu_showall']) {
         $GLOBALS['language_menu_login'] = true;
     }
 
-  // Added this $GLOBALS['concurrent_layout'] set to 3 in order to support legacy forms
-  // that may use this; note this global has been removed from the standard codebase.
+    // Added this $GLOBALS['concurrent_layout'] set to 3 in order to support legacy forms
+    // that may use this; note this global has been removed from the standard codebase.
     $GLOBALS['concurrent_layout'] = 3;
 
-// Additional logic to override theme name.
-// For RTL languages we substitute the theme name with the name of RTL-adapted CSS file.
+    // Additional logic to override theme name.
+    // For RTL languages we substitute the theme name with the name of RTL-adapted CSS file.
     $rtl_override = false;
     $rtl_portal_override = false;
     if (isset($_SESSION['language_direction']) && empty($_SESSION['patient_portal_onsite_two'])) {
@@ -469,9 +476,9 @@ if (!empty($glrow)) {
         }
     } else {
         //$_SESSION['language_direction'] is not set, so will use the default language
-        $default_lang_id = sqlQueryNoLog('SELECT lang_id FROM lang_languages WHERE lang_description = ?', array($GLOBALS['language_default']));
+        $default_lang_id = sqlQueryNoLog('SELECT lang_id FROM lang_languages WHERE lang_description = ?', array($GLOBALS['language_default'] ?? ''));
 
-        if (getLanguageDir($default_lang_id['lang_id']) === 'rtl' && !strpos($GLOBALS['css_header'], 'rtl')) {
+        if (getLanguageDir($default_lang_id['lang_id'] ?? '') === 'rtl' && !strpos($GLOBALS['css_header'], 'rtl')) {
 // @todo eliminate 1 SQL query
             $rtl_override = true;
         }
@@ -629,10 +636,13 @@ $GLOBALS['layout_search_color'] = '#ff9919';
 
 // module configurations
 // upgrade fails for versions prior to 4.2.0 since no modules table
-// so perform this check to avoid sql error
-if (!file_exists($webserver_root . "/interface/modules/")) {
-    error_log("The modules directory does not exist thus not loading modules.");
-} else {
+try {
+    $checkModulesTableExists = sqlQueryNoLog('SELECT 1 FROM `modules`', false, true);
+} catch (\Exception $ex) {
+    error_log(errorLogEscape($ex->getMessage() . $ex->getTraceAsString()));
+}
+
+if (!empty($checkModulesTableExists)) {
     $GLOBALS['baseModDir'] = "interface/modules/"; //default path of modules
     $GLOBALS['customModDir'] = "custom_modules"; //non zend modules
     $GLOBALS['zendModDir'] = "zend_modules"; //zend modules
