@@ -16,7 +16,7 @@
  */
 
 require_once("../globals.php");
-require_once("../../library/patient.inc");
+require_once("../../library/patient.inc.php");
 require_once "$srcdir/options.inc.php";
 require_once "$srcdir/appointments.inc.php";
 require_once("$srcdir/patient_tracker.inc.php");
@@ -470,7 +470,7 @@ if (!empty($_POST['form_refresh']) || !empty($_POST['form_orderby'])) {
     <tr bgcolor='<?php echo attr($bgcolor ?? ''); ?>'>
         <?php
         if (!$chk_show_drug_screens && !$chk_show_completed_drug_screens) { # the first part of this block is for the Patient Flow Board report ?>
-        <td class="detail">&nbsp;<?php echo ($docname == $lastdocname) ? "" : $docname ?>
+        <td class="detail">&nbsp;<?php echo text(($docname == $lastdocname) ? "" : $docname) ?>
         </td>
 
         <td class="detail"><?php echo text(oeFormatShortDate($appointment['pc_eventDate'])) ?>
