@@ -20,6 +20,18 @@ function js_escape($text)
     return json_encode($text);
 }
 
+/**
+ * Escape a javascript literal with a protected string
+ */
+function js_escape_protected($text, string $protected = '\r\n')
+{
+    if (empty($text)) {
+        return '""';
+    }
+    $bookmark = '___PROTECTED_STRING___';
+    return str_replace($bookmark, $protected, json_encode(str_replace($protected, $bookmark, $text)));
+}
+
 /**
  * Escape a javascript literal within html onclick attribute.
  */
@@ -41,7 +53,7 @@ function attr_url($text)
  */
 function js_url($text)
 {
-    return js_escape(urlencode($text));
+    return js_escape(urlencode($text ?? ''));
 }
 
 /**
@@ -258,7 +270,7 @@ function xlj($key)
 }
 
 /*
- * Deprecated
+ * @Deprecated
  *Translate via xl() and then escape via addslashes for use with javascript literals
  */
 function xls($key)
