@@ -100,7 +100,7 @@ $insurance_data_array = array(
 'subscriber_relationship' => xl('Subscriber Relationship') . ": ",
 'subscriber_ss' => xl('Subscriber SS') . ": ",
 'subscriber_DOB' => xl('Subscriber Date of Birth') . ": ",
-'subscriber_phone' => xl('Subscribter Phone') . ": ",
+'subscriber_phone' => xl('Subscriber Phone') . ": ",
 'subscriber_street' => xl('Subscriber Address') . ": ",
 'subscriber_postal_code' => xl('Subscriber Zip') . ": ",
 'subscriber_city' => xl('Subscriber City') . ": ",
