@@ -9,7 +9,9 @@
  * @link      https://www.open-emr.org
  * @author    Brady Miller <brady.g.miller@gmail.com>
  * @author    Jerry Padgett <sjpadgett@gmail.com>
+ * @author    Stephen Nielson <snielson@discoverandchange.com>
  * @copyright Copyright (c) 2019-2021 Brady Miller <brady.g.miller@gmail.com>
+ * @copyright Copyright (c) 2024 Care Management Solutions, Inc. <stephen.waite@cmsvt.com>
  * @license   https://github.com/openemr/openemr/blob/master/LICENSE GNU General Public License 3
  */
 
@@ -22,6 +24,7 @@ use OpenEMR\Common\Utils\CacheUtils;
 use OpenEMR\Core\Header;
 use OpenEMR\Core\Kernel;
 use OpenEMR\OeUI\OemrUI;
+use OpenEMR\OeUI\RenderFormFieldHelper;
 use OpenEMR\Services\Globals\GlobalsService;
 use OpenEMR\Services\LogoService;
 use Symfony\Component\EventDispatcher\GenericEvent;
@@ -40,6 +43,15 @@ class TwigExtension extends AbstractExtension implements GlobalsInterface
      */
     protected $kernel;
 
+    protected OemrUI $oemrUI;
+
+    protected function getOemrUiInstance($oemrSettings = array())
+    {
+        if (!isset($this->oemrUI)) {
+            $this->oemrUI = new OemrUI($oemrSettings);
+        }
+        return $this->oemrUI;
+    }
     /**
      * TwigExtension constructor.
      * @param GlobalsService $globals
@@ -160,6 +172,9 @@ class TwigExtension extends AbstractExtension implements GlobalsInterface
             new TwigFunction(
                 'csrfToken',
                 function ($subject = 'default', $fieldName = "_token") {
+                    if (empty($subject)) {
+                        $subject = 'default';
+                    }
                     return sprintf('<input type="hidden" name="%s" value="%s">', $fieldName, attr(CsrfUtils::collectCsrfToken($subject)));
                 }
             ),
@@ -189,10 +204,23 @@ class TwigExtension extends AbstractExtension implements GlobalsInterface
                     return ob_get_clean();
                 }
             ),
+            // I don't like how the OemrUi class is being used, it uses event listeners to control parts of the
+            // UI and those events can be added again and again everytime the class is instantiated so it assumes
+            // its a singleton, so we'll treat it as a singleton here, but its annoying.
+            new TwigFunction('oemrUiContainerClass', function (array $oemr_settings) {
+                $oemrUi = $this->getOemrUiInstance($oemr_settings);
+                $heading =  $oemrUi->oeContainer();
+                return $heading;
+            }),
+            new TwigFunction('oemrUiPageHeading', function (array $oemr_settings) {
+                $oemrUi = $this->getOemrUiInstance($oemr_settings);
+                $heading =  $oemrUi->pageHeading(false);
+                return $heading;
+            }),
             new TwigFunction(
                 'oemrUiBelowContainerDiv',
                 function ($oemr_settings) {
-                    $oemrUi = new OemrUI($oemr_settings);
+                    $oemrUi = $this->getOemrUiInstance($oemr_settings);
                     ob_start();
                     $oemrUi->oeBelowContainerDiv();
                     return ob_get_clean();
@@ -225,6 +253,12 @@ class TwigExtension extends AbstractExtension implements GlobalsInterface
                     return LayoutsUtils::getListItemTitle($list, $option);
                 }
             )
+            ,new TwigFunction(
+                'getAssetCacheParamRaw',
+                function () {
+                    return CacheUtils::getAssetCacheParamRaw();
+                }
+            )
         ];
     }
 
@@ -315,6 +349,18 @@ class TwigExtension extends AbstractExtension implements GlobalsInterface
                     return oeFormatShortDate($string);
                 }
             ),
+            new TwigFilter(
+                'oeFormatDateTime',
+                function ($string, $formatTime = "global", $seconds = false) {
+                    return oeFormatDateTime($string, $formatTime, $seconds);
+                }
+            ),
+            new TwigFilter(
+                'xlLayoutLabel',
+                function ($string) {
+                    return xl_layout_label($string);
+                }
+            ),
             new TwigFilter(
                 'xlListLabel',
                 function ($string) {
