@@ -16,7 +16,7 @@ class DateTime extends AbstractType implements \JsonSerializable
 {
     public $date;
 
-    public function jsonSerialize()
+    public function jsonSerialize(): mixed
     {
         $formatted = DateHelper::format_datetime_cqm($this->date);
         return $formatted;
