@@ -241,9 +241,15 @@ class FhirObservationVitalsService extends FhirServiceBase implements IPatientCo
             'category' => new FhirSearchParameterDefinition('category', SearchFieldType::TOKEN, ['category']),
             'date' => new FhirSearchParameterDefinition('date', SearchFieldType::DATETIME, ['date']),
             '_id' => new FhirSearchParameterDefinition('_id', SearchFieldType::TOKEN, [new ServiceField('uuid', ServiceField::TYPE_UUID)]),
+            '_lastUpdated' => $this->getLastModifiedSearchField()
         ];
     }
 
+    public function getLastModifiedSearchField(): ?FhirSearchParameterDefinition
+    {
+        return new FhirSearchParameterDefinition('_lastUpdated', SearchFieldType::DATETIME, ['last_updated']);
+    }
+
 
     /**
      * Inserts an OpenEMR record into the sytem.
@@ -342,6 +348,7 @@ class FhirObservationVitalsService extends FhirServiceBase implements IPatientCo
                     , "uuid" => UuidRegistry::uuidToString($uuidMappings[self::VITALS_PANEL_LOINC_CODE])
                     , "user_uuid" => $record['user_uuid']
                     , "date" => $record['date']
+                    , "last_updated" => $record['last_updated']
                 ];
                 foreach ($uuidMappings as $code => $uuid) {
                     if (!$this->isVitalSignPanelCodes($code)) {  // we will skip over our vital signs code, and any pediatric stuff
@@ -365,6 +372,7 @@ class FhirObservationVitalsService extends FhirServiceBase implements IPatientCo
                 , "user_uuid" => $record['user_uuid']
                 ,"uuid" => UuidRegistry::uuidToString($uuidMappings[$code])
                 ,"date" => $record['date']
+                , "last_updated" => $record['last_updated']
             ];
 
             $columns = $this->getColumnsForCode($code);
@@ -421,7 +429,11 @@ class FhirObservationVitalsService extends FhirServiceBase implements IPatientCo
         $observation = new FHIRObservation();
         $meta = new FHIRMeta();
         $meta->setVersionId('1');
-        $meta->setLastUpdated(UtilsService::getDateFormattedAsUTC());
+        if (!empty($dataRecord['last_updated'])) {
+            $meta->setLastUpdated(UtilsService::getLocalDateAsUTC($dataRecord['last_updated']));
+        } else {
+            $meta->setLastUpdated(UtilsService::getDateFormattedAsUTC());
+        }
         $observation->setMeta($meta);
 
         $id = new FHIRId();
