@@ -58,6 +58,16 @@ class FHIRSearchFieldFactory
         return $this->fhirUrlResolver;
     }
 
+    /**
+     * @param $fhirSearchField
+     * @param FhirSearchParameterDefinition $definition
+     * @return void
+     */
+    public function setSearchFieldDefinition(string $fhirSearchField, FhirSearchParameterDefinition $definition)
+    {
+        $this->resourceSearchParameters[$fhirSearchField] = $definition;
+    }
+
     /**
      * Checks whethere the factory has a search definition for the passed in search field name
      * @param $fhirSearchField
@@ -76,8 +86,8 @@ class FHIRSearchFieldFactory
 
     /**
      * Factory method to build a search field using the factory's search field definitions.
-     * @param $fhirSearchField The passed in parameter name for the search field the user agent sent.  Can contain search modifiers
-     * @param $fhirSearchValues The array of search values the user agent sent for the $fhirSearchField
+     * @param $fhirSearchField string The passed in parameter name for the search field the user agent sent.  Can contain search modifiers
+     * @param $fhirSearchValues array The array of search values the user agent sent for the $fhirSearchField
      * @throws \InvalidArgumentException If the factory does not have a search definition for $fhirSearchField
      * @return CompositeSearchField|DateSearchField|StringSearchField|TokenSearchField
      */
