@@ -202,6 +202,10 @@ class SQLUpgradeService
      *  desc: Change Layout edit options.
      *  arguments: mode(add or remove) layout_form_id the_edit_option comma_seperated_list_of_field_ids
      *
+     * #IfVitalsDatesNeeded
+     *  desc: Change date from zeroes to date of vitals form creation.
+     *  arguments: none
+     *
      * #EndIf
      *   all blocks are terminated with a #EndIf statement.
      *
@@ -635,6 +639,23 @@ class SQLUpgradeService
                 if ($skipping) {
                     $this->echo("<p class='text-success'>$skip_msg $line</p>\n");
                 }
+            } elseif (preg_match('/^#IfVitalsDatesNeeded/', $line)) {
+                $emptyDates = sqlStatementNoLog("SELECT fv.id as vitals_id, f.date as new_date FROM form_vitals fv LEFT JOIN forms f on fv.id = f.form_id WHERE fv.date = '0000-00-00 00:00:00' AND f.form_name = 'Vitals'");
+                if (sqlNumRows($emptyDates) > 0) {
+                    $this->echo("<p>Converting empty vital dates.</p>\n");
+                    $this->flush_echo();
+                    while ($row = sqlFetchArray($emptyDates)) {
+                        sqlStatementNoLog("UPDATE `form_vitals` SET `date` = ? WHERE `id` = ?", [$row['new_date'], $row['vitals_id']]);
+                    }
+                    $this->echo("<p class='text-success'>Completed conversion of empty vital dates</p>\n");
+                    $this->flush_echo();
+                    $skipping = false;
+                } else {
+                    $skipping = true;
+                }
+                if ($skipping) {
+                    $this->echo("<p class='text-success'>$skip_msg $line</p>\n");
+                }
             } elseif (preg_match('/^#EndIf/', $line)) {
                 $skipping = false;
             }
@@ -1004,6 +1025,7 @@ class SQLUpgradeService
     private function CreateOccupationList()
     {
         $res = sqlStatement("SELECT DISTINCT occupation FROM patient_data WHERE occupation <> ''");
+        $records = [];
         while ($row = sqlFetchArray($res)) {
             $records[] = $row['occupation'];
         }
@@ -1026,6 +1048,7 @@ class SQLUpgradeService
     private function CreateReactionList()
     {
         $res = sqlStatement("SELECT DISTINCT reaction FROM lists WHERE reaction <> ''");
+        $records = [];
         while ($row = sqlFetchArray($res)) {
             $records[] = $row['reaction'];
         }
@@ -1067,7 +1090,7 @@ class SQLUpgradeService
      */
     private function ImportDrugInformation()
     {
-        if ($GLOBALS['weno_rx_enable']) {
+        if ($GLOBALS['weno_rx_enable'] ?? false) {
             $drugs = file_get_contents('contrib/weno/erx_weno_drugs.sql');
             $drugsArray = preg_split('/;\R/', $drugs);
 
@@ -1124,12 +1147,17 @@ class SQLUpgradeService
     /**
      * Convert table engine.
      * @param string $table
-     * @param string $engine
+     * @param string $engine  has to be set to InnoDB 8-7-24
      * ADODB will fail if there was an error during conversion
      */
     private function MigrateTableEngine($table, $engine)
     {
-        $r = sqlStatement('ALTER TABLE `' . $table . '` ENGINE=?', $engine);
+        if ($engine != "InnoDB") {
+            return false;
+        }
+
+        $r = sqlStatement('ALTER TABLE `' . $table . '` ENGINE=InnoDB');
+
         return true;
     }
 
